@@ -165,8 +165,8 @@ auc.batch <- function(conc, time, group=NULL, method=c("t", "z", "boott"),  alte
   alternative <- match.arg(alternative)
   if(!is.null(group)){
     if(length(unlist(conc))!=length(unlist(group))){stop('different length of concentration and grouping lists')}
-    if(nlevels(as.factor(unlist(group))) > 2){stop("limited for comparison of 2 groups")}
-    if(nlevels(as.factor(unlist(group))) == 1) {group <- NULL}
+    if(length(unique(unlist(group))) > 2){stop("limited for comparison of 2 groups")}
+    if(length(unique(unlist(group))) == 1) {group <- NULL}
   }
   
   # handle input parameters
