@@ -5,7 +5,7 @@ nca <- function(conc, time, n.tail=3, dose=0, method=c("z", "boott"), conf.level
     nca.complete(conc, time, n.tail=n.tail, dose=dose, method=method, conf.level=conf.level, nsample=nsample, data)
   }else{
     if(design=='batch'){
-      print('Batch design currently not implemented')
+      nca.batch(conc, time, n.tail=n.tail, dose=dose, method=method, conf.level=conf.level, nsample=nsample, data)
     }else{
       if(!missing(conc) && (is.list(conc) || is.list(time))) stop('Both time and concentration need to be a vector')
       nca.ssd(conc, time, n.tail=n.tail, dose=dose, method=method, conf.level=conf.level, nsample=nsample, data)
